module Gallus
  # Internal: Log level represented in a coherent way. You can easily compare log levels between each other.
  # You're also able to get log level by string/symbol name.
  class Level
    include Comparable

    # Internal: All log levels.
    def self.all
      @all ||= []
    end

    # Internal: Shorthand to all.each.
    def self.each(&block)
      self.all.each(&block)
    end

    # Internal: Returns level defined under given name.
    def self.[](name)
      const_get(name.to_s)
    end

    attr_reader :name, :id

    # Internal: Constructor. Initializes logger with given name and identifier, then registers it.
    def initialize(name, id)
      @name, @id = name.to_s, id

      self.class.const_set(@name, self)
      self.class.all << self
    end

    def <=>(other)
      self.id <=> other.id
    rescue => err
      return nil
    end

    def to_s
      name
    end

    # Register available log levels:

    new :TRACE, 1
    new :DEBUG, 2
    new :INFO,  3
    new :WARN,  4
    new :ERROR, 5
  end
end
